@@ -44,7 +44,7 @@ test_that("pred", {
 test_that("pred fails well", {
   expect_error(pred(), "argument \"key\" is missing")
   expect_error(pred(key = "taxonKey"), "argument \"value\" is missing")
-  expect_error(pred("a", "b"), "'key' not in acceptable set")
+  expect_error(pred("a", "b"), "'a' not in acceptable set")
   expect_error(pred(5, "b"), "key must be of class character")
   # expect_error(pred("a", 5), "type must be of class character")
   # should fail well when more than one thing passed to `value`
@@ -89,8 +89,9 @@ test_that("pred_and/pred_or", {
 test_that("pred_and/pred_or fails well", {
   expect_error(pred_or(), "nothing passed")
   expect_error(pred_and(), "nothing passed")
-  expect_error(pred_or(4), "not of class 'occ_predicate'")
-  expect_error(pred_and(4), "not of class 'occ_predicate'")
+  expect_error(pred_and(pred("taxonKey", 2977832)), "must pass more than 1")
+  expect_error(pred_or(4, 5), "not of class 'occ_predicate'")
+  expect_error(pred_and(4, 5), "not of class 'occ_predicate'")
 })
 
 context("predicate builders: pred_not")
@@ -129,7 +130,7 @@ test_that("pred_in", {
 test_that("pred_in fails well", {
   expect_error(pred_in(), "argument \"key\" is missing")
   expect_error(pred_in(key = "taxonKey"), "argument \"value\" is missing")
-  expect_error(pred_in("a", "b"), "'key' not in acceptable set")
+  expect_error(pred_in("a", "b"), "'a' not in acceptable set")
   expect_error(pred_in(5, "b"), "key must be of class character")
 })
 
